@@ -1,6 +1,6 @@
 /**
  *	@file    asn1.h
- *	@version 7f5c362 (HEAD -> master)
+ *	@version 955a8d5 (HEAD -> master, origin/master, origin/HEAD)
  *
  *	ASN.1 header.
  */
@@ -68,7 +68,8 @@ enum {
 	ASN_IA5STRING = 22,
 	ASN_UTCTIME,
 	ASN_GENERALIZEDTIME,
-	ASN_GENERAL_STRING = 27,
+	ASN_VISIBLE_STRING = 26,
+	ASN_GENERAL_STRING,
 	ASN_BMPSTRING = 30
 };
 
