@@ -1,6 +1,6 @@
 /**
  *	@file    throughputTest.c
- *	@version 7f5c362 (HEAD -> master)
+ *	@version 955a8d5 (HEAD -> master, origin/master, origin/HEAD)
  *
  */
 /*
@@ -458,6 +458,12 @@ int32 psAesTestGCM(void)
 }
 #endif /* USE_AES_GCM */
 
+#ifdef USE_AES_CTR
+int32 psAesTestCTR(void)
+{
+	return PS_SUCCESS;
+}
+#endif /* USE_AES_CTR */
 #endif /* USE_AES */
 
 /******************************************************************************/
@@ -778,6 +784,9 @@ static test_t tests[] = {
 #ifdef USE_AES_GCM
 {psAesTestGCM, "***** AES-GCM TESTS *****"},
 #endif
+#ifdef USE_AES_CTR
+{psAesTestCTR, "***** AES-CTR TESTS *****"},
+#endif
 #else
 {NULL, "AES"},
 #endif
